import { ref, watchEffect, watch, toRef } from "vue";
import { createHighlighter } from "./shiki.mjs";
export async function getShikiHighlighter() {
  return createHighlighter(
    import("shiki-options.mjs").then((m) => m.shikiOptions),
    "_internal"
  );
}
export async function useShikiHighlighted(code, options = {}) {
  const _code = toRef(code);
  if ("themes" in options && !options.themes) {
    delete options.themes;
  }
  if (import.meta.server) {
    const highlighter = await getShikiHighlighter();
    return ref(highlighter.highlight(_code.value || "", options));
  }
  const highlighted = ref(options.highlighted || "");
  if (highlighted.value) {
    const unwatch = watch(_code, () => {
      unwatch();
      init();
    });
  } else {
    await init();
  }
  function init() {
    getShikiHighlighter().then((highlighter) => {
      watchEffect(() => {
        highlighted.value = highlighter.highlight(_code.value || "", options);
      });
    });
  }
  return highlighted;
}
